@@ -46,25 +46,30 @@ def extract_options(options):
     return utils.DotDict(options)
 
 
+def valid_session(sess):
+    if all(char not in sess for char in ["/", "\\", "\n"]):
+        return sess
+    else:
+        raise argparse.ArgumentTypeError(f"invalid session name {sess}")
+
+
+class RenameAction(argparse.Action):
+    def __call__(self, parser, namespace, values, option_string=None):
+        namespace.session_op = "rename"
+        try:
+            namespace.rename_to = valid_session(values[0])
+        except argparse.ArgumentTypeError as e:
+            raise argparse.ArgumentError(self, f"target: {e}")
+
+
 def parse(args):
     parser = argparse.ArgumentParser(
-        "Chatblade", description="a CLI Swiss Army Knife for ChatGPT"
+        "Chatblade",
+        description="a CLI Swiss Army Knife for ChatGPT",
+        formatter_class=lambda prog: argparse.HelpFormatter(prog, max_help_position=35),
     )
     parser.add_argument("query", type=str, nargs="*", help="Query to send to chat GPT")
-    parser.add_argument(
-        "-l",
-        "--last",
-        action="store_true",
-        help="""display the last result. 
-        If a query is given the conversation is continued""",
-    )
-    parser.add_argument(
-        "-p",
-        "--prompt-file",
-        metavar="name",
-        type=str,
-        help="prompt name - will load the prompt at ~/.config/chatblade/name as system msg",
-    )
+
     parser.add_argument(
         "--openai-api-key",
         metavar="key",
@@ -81,7 +86,6 @@ def parse(args):
     parser.add_argument(
         "-c", "--chat-gpt", choices=["3.5", "4"], help="chat GPT model", default="3.5"
     )
-
     parser.add_argument(
         "-i",
         "--interactive",
@@ -94,26 +98,97 @@ def parse(args):
         help="Stream the incoming text to the terminal",
         action="store_true",
     )
-
-    # ------ Display Options
-    parser.add_argument(
-        "-e",
-        "--extract",
-        help="extract content from response if possible (either json or code block)",
-        action="store_true",
-    )
-    parser.add_argument(
-        "-r",
-        "--raw",
-        help="print the last response as pure text, don't pretty print or format",
-        action="store_true",
-    )
     parser.add_argument(
         "-t",
         "--tokens",
         help="display what *would* be sent, how many tokens, and estimated costs",
         action="store_true",
     )
+    parser.add_argument(
+        "-p",
+        "--prompt-file",
+        metavar="name",
+        type=str,
+        help="prompt name - will load the prompt with that name at ~/.config/chatblade/name or a path to a file",
+    )
+
+    display_opts = parser.add_argument_group("result formatting options")
+    display_opts.add_argument(
+        "-e",
+        "--extract",
+        help="extract content from response if possible (either json or code block)",
+        action="store_true",
+    )
+    display_opts.add_argument(
+        "-r",
+        "--raw",
+        help="print session as pure text, don't pretty print or format",
+        action="store_true",
+    )
+    display_opts.add_argument(
+        "-n",
+        "--no-format",
+        help="do not add pretty print formatting to output",
+        action="store_true",
+    )
+    display_opts.add_argument(
+        "-o",
+        "--only",
+        help="Only display the response, omit query",
+        action="store_true",
+    )
+
+    session_opts = parser.add_argument_group("session options")
+    session_opts.add_argument(
+        "-l",
+        "--last",
+        dest="session",
+        action="store_const",
+        const=utils.scratch_session,
+        help=f"alias for '-S {utils.scratch_session}', the default session if none is specified",
+    )
+    session_opts.add_argument(
+        "-S",
+        "--session",
+        metavar="sess",
+        type=valid_session,
+        help="""initiate or continue named session""",
+    )
+    session_opts.add_argument(
+        "--session-list",
+        dest="session_op",
+        action="store_const",
+        const="list",
+        help="list sessions",
+    )
+    session_opts.add_argument(
+        "--session-path",
+        dest="session_op",
+        action="store_const",
+        const="path",
+        help="show path to session file",
+    )
+    session_opts.add_argument(
+        "--session-dump",
+        dest="session_op",
+        action="store_const",
+        const="dump",
+        help="dump session to stdout",
+    )
+    session_opts.add_argument(
+        "--session-delete",
+        dest="session_op",
+        action="store_const",
+        const="delete",
+        help="delete session",
+    )
+    session_opts.add_argument(
+        "--session-rename",
+        metavar="newsess",
+        action=RenameAction,
+        nargs=1,
+        help="rename session",
+    )
 
     # --- debug
     parser.add_argument("--debug", action="store_true", help=argparse.SUPPRESS)
